ClosureBridge

Struct ClosureBridge 

pub struct ClosureBridge {
    pub begin_edit: Box<dyn Fn(u32) + Send + Sync>,
    pub set_param: Box<dyn Fn(u32, f64) + Send + Sync>,
    pub end_edit: Box<dyn Fn(u32) + Send + Sync>,
    pub request_resize: Box<dyn Fn(u32, u32) -> bool + Send + Sync>,
    pub get_param: Box<dyn Fn(u32) -> f64 + Send + Sync>,
    pub get_param_plain: Box<dyn Fn(u32) -> f64 + Send + Sync>,
    pub format_param: Box<dyn Fn(u32) -> String + Send + Sync>,
    pub get_meter: Box<dyn Fn(u32) -> f32 + Send + Sync>,
    pub get_state: Box<dyn Fn() -> Vec<u8> + Send + Sync>,
    pub set_state: Box<dyn Fn(Vec<u8>) + Send + Sync>,
    pub transport: Box<dyn Fn() -> Option<TransportInfo> + Send + Sync>,
}
Adapter that implements EditorBridge over per-method closures.

Format wrappers that prefer to compose state inline via closures construct one of these and wrap it in an Arc<dyn EditorBridge>. Wrappers that already have a typed host-pointer struct should impl EditorBridge for that struct directly and skip this adapter; one less layer of indirection per call.

Fields

begin_edit: Box<dyn Fn(u32) + Send + Sync>set_param: Box<dyn Fn(u32, f64) + Send + Sync>end_edit: Box<dyn Fn(u32) + Send + Sync>request_resize: Box<dyn Fn(u32, u32) -> bool + Send + Sync>get_param: Box<dyn Fn(u32) -> f64 + Send + Sync>get_param_plain: Box<dyn Fn(u32) -> f64 + Send + Sync>format_param: Box<dyn Fn(u32) -> String + Send + Sync>get_meter: Box<dyn Fn(u32) -> f32 + Send + Sync>get_state: Box<dyn Fn() -> Vec<u8> + Send + Sync>set_state: Box<dyn Fn(Vec<u8>) + Send + Sync>transport: Box<dyn Fn() -> Option<TransportInfo> + Send + Sync>