#[non_exhaustive]pub enum PluginFormat {
Clap,
Vst3,
Vst2,
Au,
Lv2,
Aax,
}Expand description
The plugin format whose wrapper found a foreign state blob.
Carried in ForeignState::Raw so a migrate_state
implementation can branch per format when the old builds
serialized differently per format.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.